Struct CertificateDigest
pub struct CertificateDigest(/* private fields */);Expand description
The digest of a certificate.
Implementations
impl CertificateDigest
impl CertificateDigest
pub const ZERO: CertificateDigest
pub const ZERO: CertificateDigest
A constant representing a zero digest.
pub const MIN: CertificateDigest
pub const MIN: CertificateDigest
The lexicographically minimum digest.
pub const MAX: CertificateDigest
pub const MAX: CertificateDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> CertificateDigest
pub const fn new(digest: [u8; 32]) -> CertificateDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> CertificateDigest
pub fn generate<R>(rng: R) -> CertificateDigest
Generates a new digest from the provided random number generator.
pub fn random() -> CertificateDigest
pub fn random() -> CertificateDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(base58: T) -> Result<CertificateDigest, DigestParseError>
pub fn from_base58<T>(base58: T) -> Result<CertificateDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<CertificateDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<CertificateDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> CertificateDigest
pub const fn next_lexicographical(&self) -> CertificateDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<CertificateDigest>
pub const fn next_lexicographical_opt(&self) -> Option<CertificateDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.