Struct CheckpointDigest
pub struct CheckpointDigest(/* private fields */);Expand description
The digest of a CheckpointSummary.
Implementations
impl CheckpointDigest
impl CheckpointDigest
pub const ZERO: CheckpointDigest
pub const ZERO: CheckpointDigest
A constant representing a zero digest.
pub const MIN: CheckpointDigest
pub const MIN: CheckpointDigest
The lexicographically minimum digest.
pub const MAX: CheckpointDigest
pub const MAX: CheckpointDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> CheckpointDigest
pub const fn new(digest: [u8; 32]) -> CheckpointDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> CheckpointDigest
pub fn generate<R>(rng: R) -> CheckpointDigest
Generates a new digest from the provided random number generator.
pub fn random() -> CheckpointDigest
pub fn random() -> CheckpointDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(base58: T) -> Result<CheckpointDigest, DigestParseError>
pub fn from_base58<T>(base58: T) -> Result<CheckpointDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<CheckpointDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<CheckpointDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> CheckpointDigest
pub const fn next_lexicographical(&self) -> CheckpointDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<CheckpointDigest>
pub const fn next_lexicographical_opt(&self) -> Option<CheckpointDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.