Digest

Struct Digest 

pub struct Digest(/* private fields */);
A 32-byte Blake2b256 hash output.

BCS

A Digest’s BCS serialized form is defined by the following:

digest = %d32 32OCTET

Due to historical reasons, even though a Digest has a fixed-length of 32, IOTA’s binary representation of a Digest is prefixed with its length meaning its serialized binary form (in bcs) is 33 bytes long vs a more compact 32 bytes.

Implementations



impl Digest

pub const LENGTH: usize = 32

A constant representing the length of a digest in bytes.

pub const ZERO: Digest

A constant representing a zero digest.

pub const MIN: Digest

The lexicographically minimum digest

pub const MAX: Digest

The lexicographically maximum digest

pub const OBJECT_DELETED: Digest

A marker that signifies the object is deleted.

pub const OBJECT_WRAPPED: Digest

A marker that signifies the object is wrapped into another object.

pub const OBJECT_CANCELLED: Digest

A marker that signifies the object is cancelled.

pub const GENESIS_MARKER: Digest = Self::ZERO

A digest used to signify the parent transaction was the genesis. Note that this is not the same as the digest of the genesis transaction, which cannot be known ahead of time.

pub const fn new(digest: [u8; 32]) -> Digest

Generates a new digest from the provided 32 byte array containing u8 values.

pub fn generate<R>(rng: R) -> Digest
where R: RngCore + CryptoRng,

Generates a new digest from the provided random number generator.

pub fn random() -> Digest

pub const fn inner(&self) -> &[u8; 32]

Returns a slice to the inner array representation of this digest.

pub const fn into_inner(self) -> [u8; 32]

Returns the inner array representation of this digest.

pub const fn as_bytes(&self) -> &[u8]

Returns a slice of bytes representing the digest.

pub fn from_base58<T>(base58: T) -> Result<Digest, DigestParseError>
where T: AsRef<[u8]>,

Decodes a digest from a Base58 encoded string.

pub fn to_base58(&self) -> String

Returns a Base58 encoded string representation of this digest.

pub fn from_bytes<T>(bytes: T) -> Result<Digest, DigestParseError>
where T: AsRef<[u8]>,

Generates a digest from bytes.

pub const fn next_lexicographical(&self) -> Digest

Returns the next digest in byte-increasing order.

pub const fn next_lexicographical_opt(&self) -> Option<Digest>

Returns the next digest in byte-increasing order, or None if the result would overflow.

pub fn is_object_alive(&self) -> bool

Returns whether the digest represents an object that is neither deleted nor wrapped

pub fn is_object_deleted(&self) -> bool

Returns whether the digest represents a deleted object

pub fn is_object_wrapped(&self) -> bool

Returns whether the digest represents an object wrapped in another object.