Struct EffectsAuxDataDigest
pub struct EffectsAuxDataDigest(/* private fields */);Expand description
The digest of the auxiliary data associated with TransactionEffects.
Implementations
impl EffectsAuxDataDigest
impl EffectsAuxDataDigest
pub const ZERO: EffectsAuxDataDigest
pub const ZERO: EffectsAuxDataDigest
A constant representing a zero digest.
pub const MIN: EffectsAuxDataDigest
pub const MIN: EffectsAuxDataDigest
The lexicographically minimum digest.
pub const MAX: EffectsAuxDataDigest
pub const MAX: EffectsAuxDataDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> EffectsAuxDataDigest
pub const fn new(digest: [u8; 32]) -> EffectsAuxDataDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> EffectsAuxDataDigest
pub fn generate<R>(rng: R) -> EffectsAuxDataDigest
Generates a new digest from the provided random number generator.
pub fn random() -> EffectsAuxDataDigest
pub fn random() -> EffectsAuxDataDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(
base58: T,
) -> Result<EffectsAuxDataDigest, DigestParseError>
pub fn from_base58<T>( base58: T, ) -> Result<EffectsAuxDataDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<EffectsAuxDataDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<EffectsAuxDataDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> EffectsAuxDataDigest
pub const fn next_lexicographical(&self) -> EffectsAuxDataDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<EffectsAuxDataDigest>
pub const fn next_lexicographical_opt(&self) -> Option<EffectsAuxDataDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.