Struct MisbehaviorReportDigest
pub struct MisbehaviorReportDigest(/* private fields */);Expand description
The digest of a misbehavior report.
Implementations
impl MisbehaviorReportDigest
impl MisbehaviorReportDigest
pub const ZERO: MisbehaviorReportDigest
pub const ZERO: MisbehaviorReportDigest
A constant representing a zero digest.
pub const MIN: MisbehaviorReportDigest
pub const MIN: MisbehaviorReportDigest
The lexicographically minimum digest.
pub const MAX: MisbehaviorReportDigest
pub const MAX: MisbehaviorReportDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> MisbehaviorReportDigest
pub const fn new(digest: [u8; 32]) -> MisbehaviorReportDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> MisbehaviorReportDigest
pub fn generate<R>(rng: R) -> MisbehaviorReportDigest
Generates a new digest from the provided random number generator.
pub fn random() -> MisbehaviorReportDigest
pub fn random() -> MisbehaviorReportDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(
base58: T,
) -> Result<MisbehaviorReportDigest, DigestParseError>
pub fn from_base58<T>( base58: T, ) -> Result<MisbehaviorReportDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<MisbehaviorReportDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<MisbehaviorReportDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> MisbehaviorReportDigest
pub const fn next_lexicographical(&self) -> MisbehaviorReportDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<MisbehaviorReportDigest>
pub const fn next_lexicographical_opt(&self) -> Option<MisbehaviorReportDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.