Struct MoveAuthenticatorDigest
pub struct MoveAuthenticatorDigest(/* private fields */);Expand description
The digest of a MoveAuthenticator.
Implementations
impl MoveAuthenticatorDigest
impl MoveAuthenticatorDigest
pub const ZERO: MoveAuthenticatorDigest
pub const ZERO: MoveAuthenticatorDigest
A constant representing a zero digest.
pub const MIN: MoveAuthenticatorDigest
pub const MIN: MoveAuthenticatorDigest
The lexicographically minimum digest.
pub const MAX: MoveAuthenticatorDigest
pub const MAX: MoveAuthenticatorDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> MoveAuthenticatorDigest
pub const fn new(digest: [u8; 32]) -> MoveAuthenticatorDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> MoveAuthenticatorDigest
pub fn generate<R>(rng: R) -> MoveAuthenticatorDigest
Generates a new digest from the provided random number generator.
pub fn random() -> MoveAuthenticatorDigest
pub fn random() -> MoveAuthenticatorDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(
base58: T,
) -> Result<MoveAuthenticatorDigest, DigestParseError>
pub fn from_base58<T>( base58: T, ) -> Result<MoveAuthenticatorDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<MoveAuthenticatorDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<MoveAuthenticatorDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> MoveAuthenticatorDigest
pub const fn next_lexicographical(&self) -> MoveAuthenticatorDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<MoveAuthenticatorDigest>
pub const fn next_lexicographical_opt(&self) -> Option<MoveAuthenticatorDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.